@@ -1,10 +1,12 @@
+from rich.text import Text
+
 from textual.app import App, ComposeResult
 from textual.containers import Horizontal
 from textual.widgets import RadioButton, RadioSet
 
 
 class RadioChoicesApp(App[None]):
-    CSS_PATH = "radio_set.css"
+    CSS_PATH = "radio_set.tcss"
 
     def compose(self) -> ComposeResult:
         with Horizontal():
@@ -18,7 +20,9 @@ class RadioChoicesApp(App[None]):
                 yield RadioButton("Star Wars: A New Hope")
                 yield RadioButton("The Last Starfighter")
                 yield RadioButton(
-                    "Total Recall :backhand_index_pointing_right: :red_circle:"
+                    Text.from_markup(
+                        "Total Recall :backhand_index_pointing_right: :red_circle:"
+                    )
                 )
                 yield RadioButton("Wing Commander")
             # A RadioSet built up from a collection of strings.
