@@ -6,13 +6,13 @@ from typing import TYPE_CHECKING, Iterable, Sequence, cast
 
 from typing_extensions import Literal
 
-from .box_model import BoxModel
-from .css.scalar import Scalar
-from .css.styles import RenderStyles
-from .geometry import Size
+from textual.box_model import BoxModel
+from textual.css.scalar import Scalar
+from textual.css.styles import RenderStyles
+from textual.geometry import Size
 
 if TYPE_CHECKING:
-    from .widget import Widget
+    from textual.widget import Widget
 
 
 def resolve(
@@ -21,6 +21,10 @@ def resolve(
     gutter: int,
     size: Size,
     viewport: Size,
+    *,
+    expand: bool = False,
+    shrink: bool = False,
+    minimums: list[int] | None = None,
 ) -> list[tuple[int, int]]:
     """Resolve a list of dimensions.
 
@@ -48,8 +52,8 @@ def resolve(
         sum([scalar.value for scalar, fraction in resolved if fraction is None])
     )
 
+    total_gutter = gutter * (len(dimensions) - 1)
     if total_fraction:
-        total_gutter = gutter * (len(dimensions) - 1)
         consumed = sum([fraction for _, fraction in resolved if fraction is not None])
         remaining = max(Fraction(0), Fraction(total - total_gutter) - consumed)
         fraction_unit = Fraction(remaining, total_fraction)
@@ -63,8 +67,43 @@ def resolve(
         )
 
     fraction_gutter = Fraction(gutter)
+
+    if expand or shrink:
+        total_space = total - total_gutter
+        used_space = sum(resolved_fractions)
+        if expand:
+            remaining_space = total_space - used_space
+            if remaining_space > 0:
+                resolved_fractions = [
+                    width + Fraction(width, used_space) * remaining_space
+                    for width in resolved_fractions
+                ]
+        if shrink:
+            one = Fraction(1)
+            excess_space = used_space - total_space
+            if minimums is not None and excess_space > 0:
+                for index, (minimum_width, width) in enumerate(
+                    zip(map(Fraction, minimums), resolved_fractions)
+                ):
+                    remove_space = max(Fraction(width, used_space), one) * excess_space
+                    updated_width = max(minimum_width, width - remove_space)
+                    resolved_fractions[index] = updated_width
+                    used_space = used_space - width + updated_width
+                    excess_space = used_space - total_space
+                    if excess_space <= 0:
+                        break
+
+                used_space = sum(resolved_fractions)
+                excess_space = used_space - total_space
+
+            if excess_space > 0:
+                resolved_fractions = [
+                    width - Fraction(width, used_space) * excess_space
+                    for width in resolved_fractions
+                ]
+
     offsets = [0] + [
-        int(fraction)
+        fraction.__floor__()
         for fraction in accumulate(
             value
             for fraction in resolved_fractions
@@ -86,7 +125,7 @@ def resolve_fraction_unit(
     remaining_space: Fraction,
     resolve_dimension: Literal["width", "height"] = "width",
 ) -> Fraction:
-    """Calculate the fraction
+    """Calculate the fraction.
 
     Args:
         widget_styles: Styles for widgets with fraction units.
@@ -98,8 +137,11 @@ def resolve_fraction_unit(
     Returns:
         The value of 1fr.
     """
+    _Fraction = Fraction
     if not remaining_space or not widget_styles:
-        return Fraction(1)
+        return _Fraction(1)
+
+    initial_space = remaining_space
 
     def resolve_scalar(
         scalar: Scalar | None, fraction_unit: Fraction = Fraction(1)
@@ -129,6 +171,7 @@ def resolve_fraction_unit(
                 resolve_scalar(styles.max_width),
             )
             for styles in widget_styles
+            if styles.overlay != "screen"
         ]
     else:
         resolve = [
@@ -138,26 +181,27 @@ def resolve_fraction_unit(
                 resolve_scalar(styles.max_height),
             )
             for styles in widget_styles
+            if styles.overlay != "screen"
         ]
 
     resolved: list[Fraction | None] = [None] * len(resolve)
     remaining_fraction = Fraction(sum(scalar.value for scalar, _, _ in resolve))
 
-    while True:
+    while remaining_fraction > 0:
         remaining_space_changed = False
-        resolve_fraction = Fraction(remaining_space, remaining_fraction)
+        resolve_fraction = _Fraction(remaining_space, remaining_fraction)
         for index, (scalar, min_value, max_value) in enumerate(resolve):
             value = resolved[index]
             if value is None:
                 resolved_scalar = scalar.resolve(size, viewport_size, resolve_fraction)
                 if min_value is not None and resolved_scalar < min_value:
                     remaining_space -= min_value
-                    remaining_fraction -= Fraction(scalar.value)
+                    remaining_fraction -= _Fraction(scalar.value)
                     resolved[index] = min_value
                     remaining_space_changed = True
                 elif max_value is not None and resolved_scalar > max_value:
                     remaining_space -= max_value
-                    remaining_fraction -= Fraction(scalar.value)
+                    remaining_fraction -= _Fraction(scalar.value)
                     resolved[index] = max_value
                     remaining_space_changed = True
 
@@ -166,8 +210,8 @@ def resolve_fraction_unit(
 
     return (
         Fraction(remaining_space, remaining_fraction)
-        if remaining_space
-        else Fraction(1)
+        if remaining_fraction > 0
+        else initial_space
     )
 
 
@@ -178,6 +222,7 @@ def resolve_box_models(
     viewport_size: Size,
     margin: Size,
     resolve_dimension: Literal["width", "height"] = "width",
+    greedy: bool = True,
 ) -> list[BoxModel]:
     """Resolve box models for a list of dimensions
 
@@ -192,23 +237,39 @@ def resolve_box_models(
     Returns:
         List of resolved box models.
     """
+
     margin_width, margin_height = margin
-
-    fraction_width = Fraction(max(0, size.width - margin_width))
-    fraction_height = Fraction(max(0, size.height - margin_height))
-
+    fraction_width = Fraction(size.width)
+    fraction_height = Fraction(size.height)
+    fraction_zero = Fraction(0)
     margin_size = size - margin
 
+    margins = [widget.styles.margin.totals for widget in widgets]
+
     # Fixed box models
     box_models: list[BoxModel | None] = [
         (
             None
             if _dimension is not None and _dimension.is_fraction
             else widget._get_box_model(
-                size, viewport_size, fraction_width, fraction_height
+                size,
+                viewport_size,
+                (
+                    fraction_zero
+                    if (_width := fraction_width - margin_width) < 0
+                    else _width
+                ),
+                (
+                    fraction_zero
+                    if (_height := fraction_height - margin_height) < 0
+                    else _height
+                ),
+                greedy=greedy,
             )
         )
-        for (_dimension, widget) in zip(dimensions, widgets)
+        for (_dimension, widget, (margin_width, margin_height)) in zip(
+            dimensions, widgets, margins
+        )
     ]
 
     if None not in box_models:
@@ -218,13 +279,24 @@ def resolve_box_models(
     # If all box models have been calculated
     widget_styles = [widget.styles for widget in widgets]
     if resolve_dimension == "width":
-        total_remaining = int(sum([width for width, _, _ in filter(None, box_models)]))
+        total_remaining = int(
+            sum(
+                [
+                    box_model.width
+                    for widget, box_model in zip(widgets, box_models)
+                    if (box_model is not None and widget.styles.overlay != "screen")
+                ]
+            )
+        )
+
         remaining_space = int(max(0, size.width - total_remaining - margin_width))
         fraction_unit = resolve_fraction_unit(
             [
                 styles
                 for styles in widget_styles
-                if styles.width is not None and styles.width.is_fraction
+                if styles.width is not None
+                and styles.width.is_fraction
+                and styles.overlay != "screen"
             ],
             size,
             viewport_size,
@@ -235,14 +307,23 @@ def resolve_box_models(
         height_fraction = Fraction(margin_size.height)
     else:
         total_remaining = int(
-            sum([height for _, height, _ in filter(None, box_models)])
+            sum(
+                [
+                    box_model.height
+                    for widget, box_model in zip(widgets, box_models)
+                    if (box_model is not None and widget.styles.overlay != "screen")
+                ]
+            )
         )
+
         remaining_space = int(max(0, size.height - total_remaining - margin_height))
         fraction_unit = resolve_fraction_unit(
             [
                 styles
                 for styles in widget_styles
-                if styles.height is not None and styles.height.is_fraction
+                if styles.height is not None
+                and styles.height.is_fraction
+                and styles.overlay != "screen"
             ],
             size,
             viewport_size,
@@ -255,10 +336,7 @@ def resolve_box_models(
     box_models = [
         box_model
         or widget._get_box_model(
-            size,
-            viewport_size,
-            width_fraction,
-            height_fraction,
+            size, viewport_size, width_fraction, height_fraction, greedy=greedy
         )
         for widget, box_model in zip(widgets, box_models)
     ]
