@@ -341,7 +341,7 @@ async def test_compose_order() -> None:
     class SelectBugApp(App[None]):
         async def on_mount(self):
             await self.push_screen(MyScreen(id="my-screen"))
-            self.query_one(Select)
+            self.screen.query_one(Select)
 
     app = SelectBugApp()
     messages: list[Message] = []
@@ -646,25 +646,50 @@ async def test_of_type() -> None:
         labels = list(app.query(Label))
         assert labels[0].first_of_type
         assert not labels[0].last_of_type
+        assert labels[0].first_child
+        assert not labels[0].last_child
         assert labels[0].is_odd
         assert not labels[0].is_even
 
         assert not labels[1].first_of_type
         assert not labels[1].last_of_type
+        assert not labels[1].first_child
+        assert not labels[1].last_child
         assert not labels[1].is_odd
         assert labels[1].is_even
 
         assert not labels[2].first_of_type
         assert not labels[2].last_of_type
+        assert not labels[2].first_child
+        assert not labels[2].last_child
         assert labels[2].is_odd
         assert not labels[2].is_even
 
         assert not labels[3].first_of_type
         assert not labels[3].last_of_type
+        assert not labels[3].first_child
+        assert not labels[3].last_child
         assert not labels[3].is_odd
         assert labels[3].is_even
 
         assert not labels[4].first_of_type
         assert labels[4].last_of_type
+        assert not labels[4].first_child
+        assert labels[4].last_child
         assert labels[4].is_odd
         assert not labels[4].is_even
+
+
+async def test_click_line_api_border():
+    """Regression test for https://github.com/Textualize/textual/issues/5634"""
+
+    class MyApp(App):
+        def compose(self) -> ComposeResult:
+            self.my_log = Log()
+            self.my_log.styles.border = ("round", "white")
+            yield self.my_log
+
+    app = MyApp()
+    async with app.run_test() as pilot:
+        await pilot.pause()
+        await pilot.click("Log", (10, 0))
