@@ -3,7 +3,7 @@ from typing import cast
 import pytest
 
 from textual.widgets import Tree
-from textual.widgets._tree import NodeID
+from textual.widgets.tree import NodeID, UnknownNodeID
 
 
 def test_get_tree_node_by_id() -> None:
@@ -14,5 +14,5 @@ def test_get_tree_node_by_id() -> None:
     assert tree.get_node_by_id(tree.root.id).id == tree.root.id
     assert tree.get_node_by_id(child.id).id == child.id
     assert tree.get_node_by_id(grandchild.id).id == grandchild.id
-    with pytest.raises(Tree.UnknownNodeID):
+    with pytest.raises(UnknownNodeID):
         tree.get_node_by_id(cast(NodeID, grandchild.id + 1000))
